Regions
=======

Hierarchical code region model (file → class → function → lines).

.. automodule:: regions
   :members:
   :show-inheritance:

.. automodule:: regions.models
   :members:
   :show-inheritance:
